@@ -26,13 +26,16 @@ build_time_vars = {'ABIFLAGS': '',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
            '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
            '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-           '-Werror=format-security         -fstack-clash-protection '
-           '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
-           '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-           '-Werror=format-security         -fstack-clash-protection '
-           '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
-           '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-           '-Werror=format-security         -fstack-clash-protection',
+           '-Werror=format-security         -fstack-clash-protection -g '
+           '-ffile-prefix-map=/build/python/src=/usr/src/debug -march=armv8-a '
+           '-O3 -pipe -fstack-protector-strong -fno-plt -fexceptions         '
+           '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
+           '-fstack-clash-protection -g '
+           '-ffile-prefix-map=/build/python/src=/usr/src/debug -march=armv8-a '
+           '-O3 -pipe -fstack-protector-strong -fno-plt -fexceptions         '
+           '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
+           '-fstack-clash-protection -g '
+           '-ffile-prefix-map=/build/python/src=/usr/src/debug',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -41,7 +44,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CFLAGS': '-march=armv8-a -O3 -pipe -fstack-protector-strong '
                      '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                      '-Wformat -Werror=format-security         '
-                     '-fstack-clash-protection',
+                     '-fstack-clash-protection -g '
+                     '-ffile-prefix-map=/build/python/src=/usr/src/debug',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
@@ -58,7 +62,8 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-tzpath=/usr/share/zoneinfo' 'CFLAGS=-march=armv8-a "
                 '-O3 -pipe -fstack-protector-strong -fno-plt '
                 '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-                "-Werror=format-security         -fstack-clash-protection' "
+                '-Werror=format-security         -fstack-clash-protection -g '
+                "-ffile-prefix-map=/build/python/src=/usr/src/debug' "
                 "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' "
                 "'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
@@ -664,16 +669,22 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fstack-protector-strong -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -march=armv8-a -O3 '
-                             '-pipe -fstack-protector-strong -fno-plt '
+                             '-fstack-clash-protection -g '
+                             '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                             '-march=armv8-a -O3 -pipe '
+                             '-fstack-protector-strong -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -march=armv8-a -O3 '
-                             '-pipe -fstack-protector-strong -fno-plt '
+                             '-fstack-clash-protection -g '
+                             '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                             '-march=armv8-a -O3 -pipe '
+                             '-fstack-protector-strong -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -std=c99 -Wextra '
-                             '-Wno-unused-result -Wno-unused-parameter '
+                             '-fstack-clash-protection -g '
+                             '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                             '-std=c99 -Wextra -Wno-unused-result '
+                             '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
@@ -681,13 +692,16 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
               '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
               '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-              '-Werror=format-security         -fstack-clash-protection '
+              '-Werror=format-security         -fstack-clash-protection -g '
+              '-ffile-prefix-map=/build/python/src=/usr/src/debug '
               '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
               '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-              '-Werror=format-security         -fstack-clash-protection '
+              '-Werror=format-security         -fstack-clash-protection -g '
+              '-ffile-prefix-map=/build/python/src=/usr/src/debug '
               '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
               '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-              '-Werror=format-security         -fstack-clash-protection',
+              '-Werror=format-security         -fstack-clash-protection -g '
+              '-ffile-prefix-map=/build/python/src=/usr/src/debug',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
@@ -697,13 +711,16 @@ build_time_vars = {'ABIFLAGS': '',
                    '-Wall -march=armv8-a -O3 -pipe -fstack-protector-strong '
                    '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                    '-Wformat -Werror=format-security         '
-                   '-fstack-clash-protection -march=armv8-a -O3 -pipe '
-                   '-fstack-protector-strong -fno-plt -fexceptions         '
-                   '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-                   '-Werror=format-security         -fstack-clash-protection '
+                   '-fstack-clash-protection -g '
+                   '-ffile-prefix-map=/build/python/src=/usr/src/debug '
                    '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
                    '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
+                   '-g -ffile-prefix-map=/build/python/src=/usr/src/debug '
+                   '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
+                   '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-Werror=format-security         -fstack-clash-protection '
+                   '-g -ffile-prefix-map=/build/python/src=/usr/src/debug '
                    '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
@@ -723,17 +740,20 @@ build_time_vars = {'ABIFLAGS': '',
                         '-fstack-protector-strong -fno-plt '
                         '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                         '-Werror=format-security         '
-                        '-fstack-clash-protection -march=armv8-a -O3 -pipe '
-                        '-fstack-protector-strong -fno-plt '
-                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-                        '-Werror=format-security         '
-                        '-fstack-clash-protection -march=armv8-a -O3 -pipe '
-                        '-fstack-protector-strong -fno-plt '
-                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-                        '-Werror=format-security         '
-                        '-fstack-clash-protection -std=c99 -Wextra '
-                        '-Wno-unused-result -Wno-unused-parameter '
-                        '-Wno-missing-field-initializers '
+                        '-fstack-clash-protection -g '
+                        '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                        '-march=armv8-a -O3 -pipe -fstack-protector-strong '
+                        '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+                        '-Wformat -Werror=format-security         '
+                        '-fstack-clash-protection -g '
+                        '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                        '-march=armv8-a -O3 -pipe -fstack-protector-strong '
+                        '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+                        '-Wformat -Werror=format-security         '
+                        '-fstack-clash-protection -g '
+                        '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                        '-std=c99 -Wextra -Wno-unused-result '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
                         '-I./Include -fPIC',
